==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d5/d24/string_8cpp.js <==
var string_8cpp =
[
    [ "IcuStringIterator", "d3/dd6/classIcuStringIterator.html", "d3/dd6/classIcuStringIterator" ],
    [ "IsValidChar", "d5/d24/string_8cpp.html#a6f0d67a8e92992edf769b92b540fa087", null ],
    [ "md5sumToString", "d5/d24/string_8cpp.html#a5c07a740ab5aedbddd024854d7737eb7", null ],
    [ "seprintf", "d5/d24/string_8cpp.html#a6418ef7c89ec9b8f27279a0abdcfadaf", null ],
    [ "SkipGarbage", "d5/d24/string_8cpp.html#afdfa79eeed4de86f362788ffe6bcdf01", null ],
    [ "str_fix_scc_encoded", "d5/d24/string_8cpp.html#af045543890df1473906e485783e427c0", null ],
    [ "str_fmt", "d5/d24/string_8cpp.html#a3b79f7b7e4b1218ae443c965004df56e", null ],
    [ "str_strip_colours", "d5/d24/string_8cpp.html#a3fcdc67f9b55f19893a47491431bf62f", null ],
    [ "str_validate", "d5/d24/string_8cpp.html#acded8e35d4592c5f0a57395ffc6eea86", null ],
    [ "strecat", "d5/d24/string_8cpp.html#a3f700f64aabcf022e93c7840d91ef3ad", null ],
    [ "strecpy", "d5/d24/string_8cpp.html#ad0e02ee8042de666ac125f0bcb455c95", null ],
    [ "stredup", "d5/d24/string_8cpp.html#afc88019d81c2476923b9463f18967933", null ],
    [ "strnatcmp", "d5/d24/string_8cpp.html#a3a673f725f3c61f888708e0dfbbd202f", null ],
    [ "strtolower", "d5/d24/string_8cpp.html#ab21b40856002bb23a819f657220b8898", null ],
    [ "StrValid", "d5/d24/string_8cpp.html#aac21f5e1ef3380f0a9ef59c577a702f2", null ],
    [ "Utf8Decode", "d5/d24/string_8cpp.html#adb406c375fc972a86860b1ac67514d1e", null ],
    [ "Utf8Encode", "d5/d24/string_8cpp.html#aaf287a91a7e9de9d174d9c15d9052467", null ],
    [ "Utf8StringLength", "d5/d24/string_8cpp.html#a7a6f406f6ee59a791f12dc723b81c828", null ],
    [ "Utf8TrimString", "d5/d24/string_8cpp.html#ac4ddf5bb187cb1c07c76833256471272", null ],
    [ "ValidateString", "d5/d24/string_8cpp.html#af7b2208b79a70916d206b3db34df2a99", null ],
    [ "vseprintf", "d5/d24/string_8cpp.html#a73d42e9077cfc743ea25f02a3fb16072", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d5/d24/string_8cpp.js <==
var string_8cpp =
[
    [ "IcuStringIterator", "d3/dd6/classIcuStringIterator.html", "d3/dd6/classIcuStringIterator" ],
    [ "IsValidChar", "d5/d24/string_8cpp.html#a6f0d67a8e92992edf769b92b540fa087", null ],
    [ "md5sumToString", "d5/d24/string_8cpp.html#a5c07a740ab5aedbddd024854d7737eb7", null ],
    [ "seprintf", "d5/d24/string_8cpp.html#a6418ef7c89ec9b8f27279a0abdcfadaf", null ],
    [ "SkipGarbage", "d5/d24/string_8cpp.html#afdfa79eeed4de86f362788ffe6bcdf01", null ],
    [ "str_fix_scc_encoded", "d5/d24/string_8cpp.html#af045543890df1473906e485783e427c0", null ],
    [ "str_fmt", "d5/d24/string_8cpp.html#a3b79f7b7e4b1218ae443c965004df56e", null ],
    [ "str_strip_colours", "d5/d24/string_8cpp.html#a3fcdc67f9b55f19893a47491431bf62f", null ],
    [ "str_validate", "d5/d24/string_8cpp.html#acded8e35d4592c5f0a57395ffc6eea86", null ],
    [ "str_validate", "d5/d24/string_8cpp.html#afb698efff87d2ed4d57ab02ed7397dc0", null ],
    [ "str_validate", "d5/d24/string_8cpp.html#a81ec1eb19f5092a1ebde89bde53321c8", null ],
    [ "strecat", "d5/d24/string_8cpp.html#a3f700f64aabcf022e93c7840d91ef3ad", null ],
    [ "strecpy", "d5/d24/string_8cpp.html#ad0e02ee8042de666ac125f0bcb455c95", null ],
    [ "stredup", "d5/d24/string_8cpp.html#afc88019d81c2476923b9463f18967933", null ],
    [ "strnatcmp", "d5/d24/string_8cpp.html#a3a673f725f3c61f888708e0dfbbd202f", null ],
    [ "strtolower", "d5/d24/string_8cpp.html#ab21b40856002bb23a819f657220b8898", null ],
    [ "strtolower", "d5/d24/string_8cpp.html#a39f2b13246bf661f030a5b684bca89c8", null ],
    [ "StrValid", "d5/d24/string_8cpp.html#aac21f5e1ef3380f0a9ef59c577a702f2", null ],
    [ "Utf8Decode", "d5/d24/string_8cpp.html#adb406c375fc972a86860b1ac67514d1e", null ],
    [ "Utf8Encode", "d5/d24/string_8cpp.html#aaf287a91a7e9de9d174d9c15d9052467", null ],
    [ "Utf8Encode", "d5/d24/string_8cpp.html#a98fa8df7080360b425274e85965a2a51", null ],
    [ "Utf8Encode", "d5/d24/string_8cpp.html#ae99859f4fb807ddb8482ffa77f6b50f4", null ],
    [ "Utf8StringLength", "d5/d24/string_8cpp.html#a7a6f406f6ee59a791f12dc723b81c828", null ],
    [ "Utf8TrimString", "d5/d24/string_8cpp.html#ac4ddf5bb187cb1c07c76833256471272", null ],
    [ "ValidateString", "d5/d24/string_8cpp.html#af7b2208b79a70916d206b3db34df2a99", null ],
    [ "vseprintf", "d5/d24/string_8cpp.html#a73d42e9077cfc743ea25f02a3fb16072", null ]
];
